Home
last modified time | relevance | path

Searched refs:constant (Results 1 – 25 of 3580) sorted by relevance

12345678910>>...144

/llvm-project-15.0.7/mlir/test/IR/
H A Drepro_b120295301.mlir5 %1 = "arith.constant"() {value = dense<0.1> : tensor<1xf32>} : () -> (tensor<1xf32>)
6 %2 = "arith.constant"() {value = dense<0.1> : tensor<2xf32>} : () -> (tensor<2xf32>)
7 %3 = "arith.constant"() {value = dense<0.1> : tensor<3xf32>} : () -> (tensor<3xf32>)
8 %4 = "arith.constant"() {value = dense<0.1> : tensor<4xf32>} : () -> (tensor<4xf32>)
9 %5 = "arith.constant"() {value = dense<0.1> : tensor<5xf32>} : () -> (tensor<5xf32>)
10 %6 = "arith.constant"() {value = dense<0.1> : tensor<6xf32>} : () -> (tensor<6xf32>)
11 %7 = "arith.constant"() {value = dense<0.1> : tensor<7xf32>} : () -> (tensor<7xf32>)
12 %8 = "arith.constant"() {value = dense<0.1> : tensor<8xf32>} : () -> (tensor<8xf32>)
13 %9 = "arith.constant"() {value = dense<0.1> : tensor<9xf32>} : () -> (tensor<9xf32>)
14 %10 = "arith.constant"() {value = dense<0.1> : tensor<10xf32>} : () -> (tensor<10xf32>)
[all …]
/llvm-project-15.0.7/clang/test/Sema/
H A Darm_inline_asm_constraints.c13 : [ constant ] "j"(-1), [ input ] "r"(i) in test_j()
21 : [ constant ] "j"(0), [ input ] "r"(i) in test_j()
53 : [ constant ] "I"(-1), [ input ] "r"(i) in test_I()
58 : [ constant ] "I"(0), [ input ] "r"(i) in test_I()
63 : [ constant ] "I"(255), [ input ] "r"(i) in test_I()
68 : [ constant ] "I"(256), [ input ] "r"(i) in test_I()
107 : [ constant ] "J"(-1), [ input ] "r"(i) in test_J()
113 : [ constant ] "J"(0), [ input ] "r"(i) in test_J()
164 : [ constant ] "L"(7), [ input ] "r"(i) in test_L()
169 : [ constant ] "L"(8), [ input ] "r"(i) in test_L()
[all …]
/llvm-project-15.0.7/mlir/test/Transforms/
H A Dconstant-fold.mlir11 %0 = arith.constant 4.5 : f32
12 %1 = arith.constant 1.5 : f32
27 %0 = arith.constant 4.5 : f32
28 %1 = arith.constant 1.5 : f32
83 %0 = arith.constant 1 : i32
84 %1 = arith.constant 5 : i32
99 %c1 = arith.constant 1 : i1
226 %0 = arith.constant 4 : i32
227 %1 = arith.constant 1 : i32
228 %2 = arith.constant 0 : i32
[all …]
H A Dparallel-loop-collapsing.mlir5 %c0 = arith.constant 0 : index
6 %c1 = arith.constant 1 : index
7 %c2 = arith.constant 2 : index
8 %c3 = arith.constant 3 : index
9 %c4 = arith.constant 4 : index
10 %c5 = arith.constant 5 : index
11 %c6 = arith.constant 6 : index
12 %c7 = arith.constant 7 : index
13 %c8 = arith.constant 8 : index
14 %c9 = arith.constant 9 : index
[all …]
H A Dsccp-structured.mlir11 %cond = arith.constant true
13 %1 = arith.constant 1 : i32
31 %1 = arith.constant 1 : i32
34 %2 = arith.constant 1 : i32
49 %1 = arith.constant 1 : i32
66 %1 = arith.constant 1 : i32
69 %2 = arith.constant 2 : i32
83 %s0 = arith.constant 0 : i32
99 %s0 = arith.constant 1 : i32
159 %s0 = arith.constant 0 : i32
[all …]
H A Dcse.mlir9 %0 = arith.constant 1 : i32
12 %1 = arith.constant 1 : i32
19 %c0 = arith.constant 0 : index
20 %c1 = arith.constant 0 : index
60 %0 = arith.constant 0 : i32
61 %1 = arith.constant 1 : i32
114 %0 = arith.constant 1 : i32
128 %0 = arith.constant 1 : i32
131 %cond = arith.constant true
138 %1 = arith.constant 1 : i32
[all …]
H A Dsccp-callgraph.mlir20 %1 = arith.constant 1 : i32
43 %1 = arith.constant 1 : i32
83 %1 = arith.constant 1 : i32
93 %1 = arith.constant 1 : i32
103 %1 = arith.constant 1 : i32
113 %1 = arith.constant 1 : i32
133 %1 = arith.constant 1 : i32
152 %1 = arith.constant 1 : i32
153 %2 = arith.constant 2 : i32
162 /// non-constant.
[all …]
/llvm-project-15.0.7/mlir/test/Dialect/Arithmetic/
H A Dint-range-interface.mlir7 %c1 = arith.constant 1 : index
8 %c2 = arith.constant 2 : index
21 %c1 = arith.constant 1 : i32
22 %c2 = arith.constant 2 : i32
37 %c0 = arith.constant 0 : i64
38 %c2 = arith.constant 2 : i64
39 %c-5 = arith.constant -5 : i64
53 %c2 = arith.constant 2 : index
74 %c0 = arith.constant 0 : i16
75 %c4 = arith.constant 4 : i16
[all …]
H A Dcanonicalize.mlir30 %c0_i64 = arith.constant 0 : i64
31 %c1_i64 = arith.constant 1 : i64
51 %c0_i1 = arith.constant false
52 %c1_i1 = arith.constant true
62 %true = arith.constant true
63 %false = arith.constant false
148 %c1 = arith.constant 1 : i64
169 %c0 = arith.constant 0 : i64
178 %c0 = arith.constant 0 : i64
343 %c2 = arith.constant 2 : i8
[all …]
/llvm-project-15.0.7/mlir/test/Dialect/Math/
H A Dcanonicalize.mlir7 %c = arith.constant 0.3 : f32
16 %c = arith.constant 2.0 : f32
25 %c = arith.constant 4.0 : f32
34 %c = arith.constant 0.0 : f32
44 %c = arith.constant -1.0 : f32
53 %c = arith.constant 4.0 : f64
62 %c = arith.constant 0.0 : f64
72 %c = arith.constant -1.0 : f64
90 %c = arith.constant 2.0 : f32
146 %c = arith.constant 1 : i32
[all …]
H A Dpolynomial-approximation.mlir514 // CHECK-DAG: %[[ONE:.+]] = arith.constant 1.000000e+00
515 // CHECK-DAG: %[[N1:.+]] = arith.constant 0.144182831
516 // CHECK-DAG: %[[N2:.+]] = arith.constant -0.349992335
517 // CHECK-DAG: %[[N3:.+]] = arith.constant -0.0106783099
518 // CHECK-DAG: %[[N4:.+]] = arith.constant 1.00209987
541 // CHECK-DAG: %[[ONE:.+]] = arith.constant 1.000000e+00
542 // CHECK-DAG: %[[N1:.+]] = arith.constant 0.144182831
543 // CHECK-DAG: %[[N2:.+]] = arith.constant -0.349992335
545 // CHECK-DAG: %[[N4:.+]] = arith.constant 1.00209987
564 // CHECK-DAG: %[[PI:.+]] = arith.constant 3.14159274
[all …]
/llvm-project-15.0.7/mlir/test/mlir-cpu-runner/
H A Dmath-polynomial-approx.mlir13 %0 = arith.constant 1.25 : f32
55 %zero = arith.constant 0.0 : f32
94 %zero = arith.constant 0.0 : f32
118 %0 = arith.constant 0.01 : f32
232 %0 = arith.constant 1.0 : f32
312 %0 = arith.constant 0.0 : f32
351 %0 = arith.constant 0.0 : f32
395 %1 = arith.constant 1.0 : f32
405 %3 = arith.constant 0.5 : f32
410 %4 = arith.constant 0.0 : f32
[all …]
/llvm-project-15.0.7/llvm/test/CodeGen/X86/
H A D2007-10-15-CoalescerCrash.ll91 @.str = external constant [9 x i8] ; <ptr> [#uses=0]
94 @.str1 = external constant [20 x i8] ; <ptr> [#uses=0]
106 @.str2 = external constant [7 x i8] ; <ptr> [#uses=0]
107 @.str3 = external constant [6 x i8] ; <ptr> [#uses=0]
108 @.str4 = external constant [4 x i8] ; <ptr> [#uses=0]
109 @.str5 = external constant [11 x i8] ; <ptr> [#uses=0]
110 @.str6 = external constant [8 x i8] ; <ptr> [#uses=0]
111 @.str7 = external constant [4 x i8] ; <ptr> [#uses=0]
113 @.str8 = external constant [9 x i8] ; <ptr> [#uses=0]
114 @.str9 = external constant [3 x i8] ; <ptr> [#uses=0]
[all …]
/llvm-project-15.0.7/mlir/test/Conversion/AffineToStandard/
H A Dlower-affine.mlir12 // CHECK-NEXT: %[[c1:.*]] = arith.constant 1 : index
30 %sum_0 = arith.constant 0.0 : f32
258 %cst0 = arith.constant 0 : i64
259 %cst1 = arith.constant 1 : i64
447 %101 = arith.constant 101 : index
450 %102 = arith.constant 102 : index
577 %1 = arith.constant 11.0 : f32
617 %c0 = arith.constant 0 : index
618 %c64 = arith.constant 64 : index
634 %c64 = arith.constant 64 : index
[all …]
/llvm-project-15.0.7/clang/test/SemaOpenCL/
H A Dstorageclass.cl10 static constant int G1 = 0;
11 constant int G2 = 0;
28 static constant float g_constant_static_var = 0;
74 extern constant float g_constant_extern_var;
124 static constant int S2 = 5;
129 constant int L1 = 0;
146constant int L6 = x; // expected-error {{initializer element is not a compi…
147 global int *constant L7 = &G4;
149 …private int *constant L8 = &x; // expected-error {{initializer element is not a compi…
150 constant int *constant L9 = &L1;
[all …]
H A Dbuiltins-amdgcn-error-gfx908-param.cl23 … // expected-error{{argument to '__builtin_amdgcn_mfma_f32_32x32x1f32' must be a constant integer}}
24 … // expected-error{{argument to '__builtin_amdgcn_mfma_f32_32x32x1f32' must be a constant integer}}
25 … // expected-error{{argument to '__builtin_amdgcn_mfma_f32_32x32x1f32' must be a constant integer}}
30 … // expected-error{{argument to '__builtin_amdgcn_mfma_f32_16x16x1f32' must be a constant integer}}
31 … // expected-error{{argument to '__builtin_amdgcn_mfma_f32_16x16x1f32' must be a constant integer}}
37 …); // expected-error{{argument to '__builtin_amdgcn_mfma_f32_4x4x1f32' must be a constant integer}}
38 …); // expected-error{{argument to '__builtin_amdgcn_mfma_f32_4x4x1f32' must be a constant integer}}
39 …); // expected-error{{argument to '__builtin_amdgcn_mfma_f32_4x4x1f32' must be a constant integer}}
107 …0); // expected-error{{argument to '__builtin_amdgcn_mfma_i32_4x4x4i8' must be a constant integer}}
108 …0); // expected-error{{argument to '__builtin_amdgcn_mfma_i32_4x4x4i8' must be a constant integer}}
[all …]
H A Dbuiltins-amdgcn-error-gfx940-param.cl16 …// expected-error{{argument to '__builtin_amdgcn_mfma_i32_16x16x32_i8' must be a constant integer}}
17 …// expected-error{{argument to '__builtin_amdgcn_mfma_i32_16x16x32_i8' must be a constant integer}}
18 …// expected-error{{argument to '__builtin_amdgcn_mfma_i32_16x16x32_i8' must be a constant integer}}
23 …// expected-error{{argument to '__builtin_amdgcn_mfma_i32_32x32x16_i8' must be a constant integer}}
24 …// expected-error{{argument to '__builtin_amdgcn_mfma_i32_32x32x16_i8' must be a constant integer}}
25 …// expected-error{{argument to '__builtin_amdgcn_mfma_i32_32x32x16_i8' must be a constant integer}}
30 …/ expected-error{{argument to '__builtin_amdgcn_mfma_f32_16x16x8_xf32' must be a constant integer}}
31 …/ expected-error{{argument to '__builtin_amdgcn_mfma_f32_16x16x8_xf32' must be a constant integer}}
32 …/ expected-error{{argument to '__builtin_amdgcn_mfma_f32_16x16x8_xf32' must be a constant integer}}
37 …/ expected-error{{argument to '__builtin_amdgcn_mfma_f32_32x32x4_xf32' must be a constant integer}}
[all …]
/llvm-project-15.0.7/mlir/test/Dialect/SCF/
H A Dfor-loop-canonicalization.mlir8 %c0 = arith.constant 0 : index
9 %c2 = arith.constant 2 : index
10 %c4 = arith.constant 4 : index
27 %c0 = arith.constant 0 : index
28 %c2 = arith.constant 2 : index
29 %c4 = arith.constant 4 : index
46 %c0 = arith.constant 0 : index
47 %c2 = arith.constant 2 : index
48 %c3 = arith.constant 3 : index
49 %c4 = arith.constant 4 : index
[all …]
H A Dloop-pipelining.mlir25 %c0 = arith.constant 0 : index
26 %c1 = arith.constant 1 : index
27 %c4 = arith.constant 4 : index
28 %cf = arith.constant 1.0 : f32
64 %c0 = arith.constant 0 : index
65 %c3 = arith.constant 3 : index
67 %cf = arith.constant 1.0 : f32
157 %c0 = arith.constant 0 : index
158 %c1 = arith.constant 1 : index
159 %c4 = arith.constant 4 : index
[all …]
/llvm-project-15.0.7/llvm/test/Bitcode/
H A Dlinkage-types-3.2.ll17 @private.var = private constant i32 0
18 ; CHECK: @private.var = private constant i32 0{{$}}
20 @linker_private.var = linker_private constant i32 0
29 @internal.var = internal constant i32 0
30 ; CHECK: @internal.var = internal constant i32 0{{$}}
35 @linkonce.var = linkonce constant i32 0
38 @weak.var = weak constant i32 0
39 ; CHECK: @weak.var = weak constant i32 0, comdat{{$}}
41 @linkonce_odr.var = linkonce_odr constant i32 0
47 @external.var = external constant i32
[all …]
/llvm-project-15.0.7/llvm/test/Linker/
H A D2004-05-07-TypeResolution1.ll11 @str1 = constant [1 x i8] zeroinitializer ; <[1 x i8]*> [#uses=0]
12 @str2 = constant [2 x i8] zeroinitializer ; <[2 x i8]*> [#uses=0]
13 @str3 = constant [3 x i8] zeroinitializer ; <[3 x i8]*> [#uses=0]
14 @str4 = constant [4 x i8] zeroinitializer ; <[4 x i8]*> [#uses=0]
15 @str5 = constant [5 x i8] zeroinitializer ; <[5 x i8]*> [#uses=0]
16 @str6 = constant [6 x i8] zeroinitializer ; <[6 x i8]*> [#uses=0]
17 @str7 = constant [7 x i8] zeroinitializer ; <[7 x i8]*> [#uses=0]
18 @str8 = constant [8 x i8] zeroinitializer ; <[8 x i8]*> [#uses=0]
19 @str9 = constant [9 x i8] zeroinitializer ; <[9 x i8]*> [#uses=0]
20 @stra = constant [10 x i8] zeroinitializer ; <[10 x i8]*> [#uses=0]
[all …]
/llvm-project-15.0.7/mlir/test/Dialect/Affine/SuperVectorize/
H A Dvector_utils.mlir8 // CHECK-NOT:matched: {{.*}} = arith.constant 0{{.*}}
9 // CHECK-NOT:matched: {{.*}} = arith.constant 1{{.*}}
13 %c0 = arith.constant 0 : index
14 %cst = arith.constant 1.000000e+00 : f32
17 %cst_1 = arith.constant dense<1.000000e+00> : vector<8x256xf32>
23 %cst_c = arith.constant dense<1.000000e+00> : vector<3x4x5x8xf32>
25 %cst_d = arith.constant dense<1.000000e+00> : vector<3x4x4x8xf32>
30 // CHECK-NOT:matched: {{.*}} = arith.constant 7{{.*}}
31 // CHECK-NOT:matched: {{.*}} = arith.constant 42{{.*}}
34 %c7 = arith.constant 7 : index
[all …]
/llvm-project-15.0.7/clang/test/CodeGenObjC/
H A Dreorder-synthesized-ivars.m41 // CHECK: @{{.*}} = private unnamed_addr constant [10 x i8] c"_boolean1
42 // CHECK: @{{.*}} = private unnamed_addr constant [10 x i8] c"_boolean2
50 // CHECK: @{{.*}} = private unnamed_addr constant [9 x i8] c"_object1
51 // CHECK: @{{.*}} = private unnamed_addr constant [9 x i8] c"_object2
52 // CHECK: @{{.*}} = private unnamed_addr constant [9 x i8] c"_object3
53 // CHECK: @{{.*}} = private unnamed_addr constant [9 x i8] c"_object4
54 // CHECK: @{{.*}} = private unnamed_addr constant [9 x i8] c"_object5
55 // CHECK: @{{.*}} = private unnamed_addr constant [9 x i8] c"_object6
56 // CHECK: @{{.*}} = private unnamed_addr constant [9 x i8] c"_object7
57 // CHECK: @{{.*}} = private unnamed_addr constant [9 x i8] c"_object8
[all …]
/llvm-project-15.0.7/llvm/test/Transforms/LowerConstantIntrinsics/
H A Dconstant-intrinsics.ll1 ; RUN: opt -lower-constant-intrinsics -S < %s | FileCheck %s
28 %v = call i1 @llvm.is.constant.i32(i32 %in)
46 ;; CHECK-NOT: llvm.is.constant
50 %v = call i1 @llvm.is.constant.i64(i64 %os1)
61 %1 = tail call i1 @llvm.is.constant.i32(i32 %0)
85 ; CHECK-NOT: llvm.is.constant
86 %v1 = call i1 @llvm.is.constant.i256(i256 %int)
87 %v2 = call i1 @llvm.is.constant.f32(float %float)
91 %v6 = call i1 @llvm.is.constant.p0i64(i64* %ptr)
93 %c1 = call i1 @llvm.is.constant.i256(i256 -1)
[all …]
/llvm-project-15.0.7/mlir/test/Integration/Dialect/Vector/CPU/
H A Dtest-scatter.mlir9 %c0 = arith.constant 0: index
16 %c0 = arith.constant 0: index
17 %c1 = arith.constant 1: index
18 %c8 = arith.constant 8: index
19 %z = arith.constant 0.0: f32
45 %i0 = arith.constant 0: i32
46 %i1 = arith.constant 1: i32
47 %i2 = arith.constant 2: i32
48 %i3 = arith.constant 3: i32
49 %i4 = arith.constant 4: i32
[all …]

12345678910>>...144